@@ -74,6 +74,7 @@ Example:
 """
 import sys
 import logging
+import types
 from functools import wraps
 
 # JSON library importing
@@ -266,10 +267,16 @@ class JSONRPCService(object):
         """
         Returns number of mandatory arguments required by given function.
         """
-        if f.func_defaults is None:
-            return f.func_code.co_argcount
+        argcount = f.func_code.co_argcount
 
-        return f.func_code.co_argcount - len(f.func_defaults)
+        # account for "self" getting passed to class instance methods
+        if isinstance(f, types.MethodType):
+            argcount -= 1
+            
+        if f.func_defaults is None:
+            return argcount
+
+        return argcount - len(f.func_defaults)
 
     def _max_args(self, f):
         """
